;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "toml" "20250729.635"
  "TOML (Tom's Obvious, Minimal Language) parser."
  ()
  :url "https://github.com/gongo/emacs-toml"
  :commit "8d8cefa2a0590ed4b68064a7a55a552c0a16a68a"
  :revdesc "8d8cefa2a059"
  :keywords '("toml" "parser")
  :authors '(("Wataru MIYAGUNI" . "gonngo@gmail.com"))
  :maintainers '(("Wataru MIYAGUNI" . "gonngo@gmail.com")))
